@@ -13,9 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import proto  # type: ignore
+
+__protobuf__ = proto.module(
+    package="google.devtools.artifactregistry.v1",
+    manifest={
+        "OperationMetadata",
+    },
+)
 
 
-__protobuf__ = proto.module(package="google.devtools.artifactregistry.v1", manifest={},)
+class OperationMetadata(proto.Message):
+    r"""Metadata type for longrunning-operations, currently empty."""
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
