@@ -15,31 +15,27 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.artifactregistry_v1beta2.types import apt_artifact
-from google.cloud.artifactregistry_v1beta2.types import file
-from google.cloud.artifactregistry_v1beta2.types import package
-from google.cloud.artifactregistry_v1beta2.types import repository
-from google.cloud.artifactregistry_v1beta2.types import repository as gda_repository
-from google.cloud.artifactregistry_v1beta2.types import settings
-from google.cloud.artifactregistry_v1beta2.types import tag
-from google.cloud.artifactregistry_v1beta2.types import tag as gda_tag
-from google.cloud.artifactregistry_v1beta2.types import version
-from google.cloud.artifactregistry_v1beta2.types import yum_artifact
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
+
+from google.cloud.artifactregistry_v1beta2.types import apt_artifact, file, package
+from google.cloud.artifactregistry_v1beta2.types import repository as gda_repository
+from google.cloud.artifactregistry_v1beta2.types import repository
+from google.cloud.artifactregistry_v1beta2.types import settings
+from google.cloud.artifactregistry_v1beta2.types import tag
+from google.cloud.artifactregistry_v1beta2.types import tag as gda_tag
+from google.cloud.artifactregistry_v1beta2.types import version, yum_artifact
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -97,6 +93,7 @@ class ArtifactRegistryTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -176,10 +173,14 @@ class ArtifactRegistryTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_repository: gapic_v1.method.wrap_method(
-                self.create_repository, default_timeout=30.0, client_info=client_info,
+                self.create_repository,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.update_repository: gapic_v1.method.wrap_method(
-                self.update_repository, default_timeout=30.0, client_info=client_info,
+                self.update_repository,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.delete_repository: gapic_v1.method.wrap_method(
                 self.delete_repository,
@@ -336,10 +337,14 @@ class ArtifactRegistryTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_tag: gapic_v1.method.wrap_method(
-                self.create_tag, default_timeout=30.0, client_info=client_info,
+                self.create_tag,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.update_tag: gapic_v1.method.wrap_method(
-                self.update_tag, default_timeout=30.0, client_info=client_info,
+                self.update_tag,
+                default_timeout=30.0,
+                client_info=client_info,
             ),
             self.delete_tag: gapic_v1.method.wrap_method(
                 self.delete_tag,
@@ -356,7 +361,9 @@ class ArtifactRegistryTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.set_iam_policy: gapic_v1.method.wrap_method(
-                self.set_iam_policy, default_timeout=None, client_info=client_info,
+                self.set_iam_policy,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_iam_policy: gapic_v1.method.wrap_method(
                 self.get_iam_policy,
@@ -392,9 +399,9 @@ class ArtifactRegistryTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -623,5 +630,9 @@ class ArtifactRegistryTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ArtifactRegistryTransport",)
